<?php

namespace App\Admin\Controllers;

use App\Handlers\AilOss;
use OSS\Core\OssException;
use Dcat\Admin\Traits\HasUploadedFile;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Storage;
use Intervention\Image\Facades\Image;

class UploadController
{

    use HasUploadedFile;

    /**
     * 删除OSS私有桶资源文件
     */
    public function deleteOssFile()
    {
        $ossPath = request()->post('key') ?? '';
        $aliOss = new AilOss();
        $res = $aliOss->delete($ossPath);
        return $res ? $this->responseDeleted() : $this->responseDeleteFailed('文件删除失败');
    }

    /**
     * 删除OSS公有桶资源文件
     */
    public function deletePublicOssFile()
    {
        $ossPath = request()->post('key') ?? '';
        $aliOss = new AilOss();
        if (strstr($ossPath, 'aliyuncs') !== false) {
            $res = $aliOss->delete($ossPath); //, 'OSS_BUCKET'
            return $res ? $this->responseDeleted() : $this->responseDeleteFailed('文件删除失败');
        } else {
            return $this->deleteFileAndResponse();
        }
    }

    public function merchantUpload()
    {
        $disk = $this->disk();

        // 判断是否是删除文件请求
        if ($this->isDeleteRequest()) {

            // 删除文件并响应
            return $this->deleteFileAndResponse();
        }

        // 获取上传的文件
        $file = $this->file();
        //获取文件扩展名
        $ext = $file->getClientOriginalExtension();
        $img  = Image::make($file->getRealPath())
            ->resize(640, null, function ($constraint) {
                $constraint->aspectRatio();
                $constraint->upsize();
            })->encode($ext, 90);

        $dir     = '/merchant/' . date("Ymd");
        $newName = md5(uniqid()) . '.' . $ext;

        $path   = "{$dir}/$newName";
        $result = $disk->put($path, $img);

        return $result
            ? $this->responseUploaded($path, $disk->url($path))
            : $this->responseErrorMessage('文件上传失败');
    }


    public function userUpload()
    {
        $disk = $this->disk();

        // 判断是否是删除文件请求
        if ($this->isDeleteRequest()) {

            // 删除文件并响应
            return $this->deleteFileAndResponse();
        }

        // 获取上传的文件
        $file = $this->file();
        //获取文件扩展名
        $ext = $file->getClientOriginalExtension();
        $img  = Image::make($file->getRealPath())
            ->resize(640, null, function ($constraint) {
                $constraint->aspectRatio();
                $constraint->upsize();
            })->encode($ext, 90);

        $dir     = '/user';
        $newName = md5(uniqid()) . '.' . $ext;

        $path   = "{$dir}/$newName";
        $result = $disk->put($path, $img);

        return $result
            ? $this->responseUploaded($path, $disk->url($path))
            : $this->responseErrorMessage('文件上传失败');
    }

    /**
     * 上传资源库图片
     */
    public function goodsUpload()
    {
        $aliOss = new AilOss();

        // 获取上传的文件
        $file = $this->file();

        $ext = $file->getClientOriginalExtension();
        Image::make($file->getRealPath())
            ->resize(640, null, function ($constraint) {
                $constraint->aspectRatio();
                $constraint->upsize();
            })->encode('jpg', 90);

        $fileName = md5(uniqid()) . '.' . $ext;
        $date = date('Ymd');
        $ossFilePath =  'goods/' . $date . '/' . $fileName;
        //获取文件的绝对路径
        $path = $file->getRealPath();
        $res = $aliOss->upload($ossFilePath, $path, 'OSS_PUBLIC_BUCKET');

        return $res
            ? $this->responseUploaded(env('OSS_PUBLIC_IMAGE_URL') . $ossFilePath, '')
            : $this->responseErrorMessage('文件上传失败');
    }


    public function goodsUpload2()
    {
        $disk = $this->disk();

        // 判断是否是删除文件请求
        if ($this->isDeleteRequest()) {

            // 删除文件并响应
            return $this->deleteFileAndResponse();
        }

        // 获取上传的文件
        $file = $this->file();

        //获取文件扩展名
        $ext = $file->getClientOriginalExtension();
        $img  = Image::make($file->getRealPath())
            ->resize(640, null, function ($constraint) {
                $constraint->aspectRatio();
                $constraint->upsize();
            })->encode($ext, 90);

        $dir     = '/goods/' . date("Ymd");
        $newName = md5(uniqid()) . '.' . $ext;

        $path   = "{$dir}/$newName";
        $result = $disk->put($path, $img);

        return $result
            ? $this->responseUploaded($path, $disk->url($path))
            : $this->responseErrorMessage('文件上传失败');
    }

    //商品规格图
    public function uploadSkuImage(Request $request)
    {
        $aliOss = new AilOss();
        if ($request->hasFile('file')) {
            $file = $request->file('file');
            $disk = $this->disk();
            //获取文件扩展名
            $ext = $file->getClientOriginalExtension();

            $fileName = md5(uniqid()) . '.' . $ext;
            $date = date('Ymd');
            $path = $file->getRealPath();
            $ossFilePath =  'goods/' . $date . '/' . $fileName;
            $res = $aliOss->upload($ossFilePath, $path, 'OSS_PUBLIC_BUCKET');

            return ['url' => env('OSS_PUBLIC_IMAGE_URL') . $ossFilePath];
        }
    }
    public function uploadSkuImage2(Request $request)
    {
        if ($request->hasFile('file')) {
            $file = $request->file('file');
            //$disk = Storage::disk('cosv5');
            // $ext = $file->getClientOriginalExtension();
            $disk = $this->disk();
            // $url = 'sku';
            // $res = $disk->put($url, $file);
            //获取文件扩展名
            $ext = $file->getClientOriginalExtension();
            $img  = Image::make($file->getRealPath())
                ->resize(640, null, function ($constraint) {
                    $constraint->aspectRatio();
                    $constraint->upsize();
                })->encode($ext, 90);

            $dir     = '/goods/' . date("Ymd");
            $newName = md5(uniqid()) . '.' . $ext;

            $path   = "{$dir}/$newName";
            $result = $disk->put($path, $img);

            $url = $result ? $path : '';

            // 返回格式
            return ['url' => env('IMAGE_URL') . $url];
        }
        return [];
    }

    public function carouselUpload()
    {
        $aliOss = new AilOss();

        // 获取上传的文件
        $file = $this->file();;
        Image::make($file->getRealPath())
            ->resize(640, null, function ($constraint) {
                $constraint->aspectRatio();
                $constraint->upsize();
            })->encode('jpg', 90);

        $fileName = md5(uniqid()) . '.jpg';
        $date = date('Ymd');
        $ossFilePath =  'carousel/' . $date . '/' . $fileName;
        //获取文件的绝对路径
        $path = $file->getRealPath();
        $res = $aliOss->upload($ossFilePath, $path, 'OSS_PUBLIC_BUCKET');

        return $res
            ? $this->responseUploaded(env('OSS_PUBLIC_IMAGE_URL') . $ossFilePath, '')
            : $this->responseErrorMessage('文件上传失败');
    }
    public function carouselUpload2()
    {
        $disk = $this->disk();

        // 判断是否是删除文件请求
        if ($this->isDeleteRequest()) {

            // 删除文件并响应
            return $this->deleteFileAndResponse();
        }

        // 获取上传的文件
        $file = $this->file();
        //获取文件扩展名
        $ext = $file->getClientOriginalExtension();
        $img  = Image::make($file->getRealPath())
            ->resize(640, null, function ($constraint) {
                $constraint->aspectRatio();
                $constraint->upsize();
            })->encode($ext, 90);

        $dir     = '/carousel';
        $newName = md5(uniqid()) . '.' . $ext;

        $path   = "{$dir}/$newName";
        $result = $disk->put($path, $img);

        return $result
            ? $this->responseUploaded($path, $disk->url($path))
            : $this->responseErrorMessage('文件上传失败');
    }

    public function articlelUpload()
    {
        $disk = $this->disk();

        // 判断是否是删除文件请求
        if ($this->isDeleteRequest()) {

            // 删除文件并响应
            return $this->deleteFileAndResponse();
        }

        // 获取上传的文件
        $file = $this->file();
        //获取文件扩展名
        $ext = $file->getClientOriginalExtension();
        $img  = Image::make($file->getRealPath())
            ->resize(640, null, function ($constraint) {
                $constraint->aspectRatio();
                $constraint->upsize();
            })->encode($ext, 90);

        $dir     = '/article';
        $newName = md5(uniqid()) . '.' . $ext;

        $path   = "{$dir}/$newName";
        $result = $disk->put($path, $img);

        return $result
            ? $this->responseUploaded($path, $disk->url($path))
            : $this->responseErrorMessage('文件上传失败');
    }
}
